ProjectFile

Struct ProjectFile 

pub struct ProjectFile { /* private fields */ }

Implementations

Source

impl ProjectFile

pub unsafe fn from_raw(handle: NonNull<BNProjectFile>) -> Self

pub fn project(&self) -> Ref<Project>

Get the project that owns this file

pub fn path_on_disk(&self) -> Option<PathBuf>

Get the path on disk to this file’s contents

pub fn path_in_project(&self) -> PathBuf

Get the path in the project to this file’s contents

pub fn exists_on_disk(&self) -> bool

Check if this file’s contents exist on disk

pub fn id(&self) -> String

Get the unique id of this file

pub fn name(&self) -> String

Get the name of this file

pub fn set_name(&self, value: &str) -> bool

Set the name of this file

pub fn description(&self) -> String

Get the description of this file

pub fn set_description(&self, value: &str) -> bool

Set the description of this file

pub fn creation_time(&self) -> SystemTime

Get the file creation time

pub fn folder(&self) -> Option<Ref<ProjectFolder>>

Get the folder that contains this file

pub fn set_folder(&self, folder: Option<&ProjectFolder>) -> bool

Set the folder that contains this file

pub fn export(&self, dest: &Path) -> bool

Export this file to disk, `true’ if the export succeeded

  • dest - Destination file path for the exported contents, passing a directory will append the file name.
pub fn add_dependency(&self, file: Ref<ProjectFile>) -> bool

Add a ProjectFile as a dependency of this file

pub fn remove_dependency(&self, file: Ref<ProjectFile>) -> bool

Remove a ProjectFile as a dependency of this file

pub fn get_dependencies(&self) -> Array<ProjectFile>

Get the ProjectFiles that this file depends on

pub fn get_required_by(&self) -> Array<ProjectFile>

Get the ProjectFiles that depend on this file